﻿Imports System.IO

Public Class TicketInformationForm

   ' stores events
   Private communityEvents As _
      New System.Collections.Generic.List(Of CommunityEvent)()

   ' populates ComboBox with current day's events (if any)
   Private Sub CreateEventList()

      Dim currentEvent As CommunityEvent ' control variable

      ' stores event information in List for selected day
      ExtractData(dateMonthCalendar.SelectionStart)

      ' remove any items in ComboBox
      eventComboBox.Items.Clear()

      ' add each event's name to ComboBox
      If communityEvents.Count > 0 Then
         For Each currentEvent In communityEvents
            ' extract and display event name
            eventComboBox.Items.Add(currentEvent.Name)
         Next

         ' inform user that events are scheduled
         eventComboBox.Text = " - Events - "
         descriptionTextBox.Text = "Pick an event."

      Else ' inform user that no events are scheduled
         eventComboBox.Text = " - No Events - "
         descriptionTextBox.Text = "No events today."
      End If
   End Sub ' CreateEventList

   ' extracts event data for a specified day from calendar.txt
   Private Sub ExtractData(ByVal currentDate As Date)
      ' set to selected date in MonthCalendar control
      Dim chosenDay As Integer = currentDate.Day
      Dim eventInfo As String() ' array of event info from text file
      Dim fileDay As Integer ' day of event from file

      communityEvents.Clear() ' clear the List of events

      ' initialize StreamReader to read lines from file
      Dim input As StreamReader = New StreamReader("calendar.txt")
      Dim line As String ' holds a record from the file

      ' loop through lines in file
      Do Until input.EndOfStream
         line = input.ReadLine() ' read the next record in the file

         ' return an array of strings containing the record's fields
         eventInfo = line.Split(ControlChars.Tab)

         fileDay = Convert.ToInt32(eventInfo(0)) ' extract day

         ' if event scheduled for specified day, store information
         If fileDay = chosenDay Then
            ' create the CommunityEvent object
            Dim newEvent As New CommunityEvent()
            newEvent.Day = fileDay
            newEvent.Time = eventInfo(1)
            newEvent.Price = Convert.ToDecimal(eventInfo(2))
            newEvent.Name = eventInfo(3)
            newEvent.Description = eventInfo(4)

            communityEvents.Add(newEvent) ' add event to the List
         End If
      Loop ' End Do Until
   End Sub ' ExtractData

   ' handles Form's Load event
   Private Sub TicketInformationForm_Load( _
      ByVal sender As System.Object, ByVal e As System.EventArgs) _
      Handles MyBase.Load

      ' display any events scheduled for today in ComboBox
      CreateEventList() ' display events scheduled for today
   End Sub ' TicketInformationForm_Load

   ' handles MonthCalendar's DateChanged event
   Private Sub dateMonthCalendar_DateChanged( _
      ByVal sender As System.Object, ByVal e As  _
      System.Windows.Forms.DateRangeEventArgs) _
      Handles dateMonthCalendar.DateChanged

      ' display any events for the specified date in ComboBox
      CreateEventList()
   End Sub ' dateMonthCalendar_DateChanged

   ' handles ComboBox's SelectedIndexChanged event
   Private Sub eventComboBox_SelectedIndexChanged(ByVal sender As  _
      System.Object, ByVal e As System.EventArgs) _
      Handles eventComboBox.SelectedIndexChanged

      ' get the event selected in the ComboBox
      Dim selectedEvent As CommunityEvent = _
         communityEvents(eventComboBox.SelectedIndex)

      ' place time, price and description of event in TextBox
      descriptionTextBox.Text = _
         selectedEvent.Time & ControlChars.CrLf & _
         "Price: $" & selectedEvent.Price & ControlChars.CrLf & _
         selectedEvent.Description
   End Sub ' eventComboBox_SelectedIndexChanged
End Class ' TicketInformationForm

' **************************************************************************
' * (C) Copyright 1992-2009 by Deitel & Associates, Inc. and               *
' * Pearson Education, Inc. All Rights Reserved.                           *
' *                                                                        *
' * DISCLAIMER: The authors and publisher of this book have used their     *
' * best efforts in preparing the book. These efforts include the          *
' * development, research, and testing of the theories and programs        *
' * to determine their effectiveness. The authors and publisher make       *
' * no warranty of any kind, expressed or implied, with regard to these    *
' * programs or to the documentation contained in these books. The authors *
' * and publisher shall not be liable in any event for incidental or       *
' * consequential damages in connection with, or arising out of, the       *
' * furnishing, performance, or use of these programs.                     *
' **************************************************************************